@@ -9,6 +9,7 @@ from astropy.cosmology import Planck18
 import astropy.table
 import extinction
 import sncosmo
+import pkg_resources
 import lcdata
 
 import torch
@@ -20,7 +21,7 @@ from torch.utils.data import DataLoader
 from .light_curve import preprocess_light_curve, grid_to_time, time_to_grid, \
     SIDEREAL_SCALE
 from .utils import frac_to_mag, parse_device
-from .settings import parse_settings
+from .settings import parse_settings, default_model
 from .sncosmo import ParsnipSncosmoSource
 
 
@@ -302,7 +303,7 @@ class ParsnipModel(nn.Module):
 
         Returns
         -------
-        `numpy.ndarray`
+        `~numpy.ndarray`
             Band weights for each redshift/band combination
         """
         # Figure out the locations to sample at for each redshift.
@@ -367,7 +368,7 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        dataset : `lcdata.Dataset`
+        dataset : `~lcdata.Dataset`
             Dataset to preprocess
         chunksize : int, optional
             Number of light curves to process at a time, by default 64
@@ -376,7 +377,7 @@ class ParsnipModel(nn.Module):
 
         Returns
         -------
-        `lcdata.Dataset`
+        `~lcdata.Dataset`
             Preprocessed dataset
         """
         import lcdata
@@ -415,7 +416,7 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        light_curves : List[`astropy.table.Table`]
+        light_curves : List[`~astropy.table.Table`]
             List of light curves to augment
         as_table : bool, optional
             Whether to return the light curves as astropy Tables, by default True.
@@ -497,18 +498,18 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        light_curves : List[`astropy.table.Table`]
+        light_curves : List[`~astropy.table.Table`]
             Light curves to extract data from
 
         Returns
         -------
-        input_data : `torch.FloatTensor`
+        input_data : `~torch.FloatTensor`
             Data that is used as input to the ParSNIP encoder
-        compare_data : `torch.FloatTensor`
+        compare_data : `~torch.FloatTensor`
             Data that is used for comparisons with the output of the ParSNIP decoder
-        redshifts : `torch.FloatTensor`
+        redshifts : `~torch.FloatTensor`
             Redshifts of each light curve
-        compare_band_indices : `torch.LongTensor`
+        compare_band_indices : `~torch.LongTensor`
             Band indices for each observation that will be compared
         """
         redshifts = []
@@ -723,14 +724,14 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        dataset : `lcdata.Dataset`
+        dataset : `~lcdata.Dataset`
             Dataset to load
         augment : bool, optional
             Whether to augment the dataset, by default False
 
         Returns
         -------
-        `torch.utils.data.DataLoader`
+        `~torch.utils.data.DataLoader`
             PyTorch DataLoader for the dataset
         """
         # Preprocess the dataset if it isn't already.
@@ -759,14 +760,14 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        input_data : `torch.FloatTensor`
+        input_data : `~torch.FloatTensor`
             Input data representing a set of gridded light curves
 
         Returns
         -------
-        `torch.FloatTensor`
+        `~torch.FloatTensor`
             Mean predictions for each latent variable
-        `torch.FloatTensor`
+        `~torch.FloatTensor`
             Log-variance predictions for each latent variable
         """
         # Apply common encoder blocks
@@ -807,19 +808,19 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        encoding : `torch.FloatTensor`
+        encoding : `~torch.FloatTensor`
             Coordinates in the ParSNIP intrinsic latent space for each light curve
-        phases : `torch.FloatTensor`
+        phases : `~torch.FloatTensor`
             Phases to decode each light curve at
-        color : `torch.FloatTensor`
+        color : `~torch.FloatTensor`
             Color of each light curve
-        amplitude : `torch.FloatTensor`, optional
+        amplitude : `~torch.FloatTensor`, optional
             Amplitude to scale each light curve by, by default no scaling will be
             applied.
 
         Returns
         -------
-        `torch.FloatTensor`
+        `~torch.FloatTensor`
             Predicted spectra
         """
         scale_phases = phases / (self.settings['time_window'] // 2)
@@ -847,27 +848,27 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        encoding : `torch.FloatTensor`
+        encoding : `~torch.FloatTensor`
             Coordinates in the ParSNIP intrinsic latent space for each light curve
-        ref_times : `torch.FloatTensor`
+        ref_times : `~torch.FloatTensor`
             Reference time for each light curve
-        color : `torch.FloatTensor`
+        color : `~torch.FloatTensor`
             Color of each light curve
-        times : `torch.FloatTensor`
+        times : `~torch.FloatTensor`
             Times to predict each light curve at
-        redshifts : `torch.FloatTensor`
+        redshifts : `~torch.FloatTensor`
             Redshift of each light curve
-        band_indices : `torch.LongTensor`
+        band_indices : `~torch.LongTensor`
             Band indices for each observation
-        amplitude : `torch.FloatTensor`, optional
+        amplitude : `~torch.FloatTensor`, optional
             Amplitude to scale each light curve by, by default no scaling will be
             applied
 
         Returns
         -------
-        `torch.FloatTensor`
+        `~torch.FloatTensor`
             Model spectra
-        `torch.FloatTensor`
+        `~torch.FloatTensor`
             Model photometry
         """
         phases = (
@@ -935,7 +936,7 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        light_curves : List[`astropy.table.Table`]
+        light_curves : List[`~astropy.table.Table`]
             List of light curves
         sample : bool, optional
             If True (default), sample from the posterior distribution. If False, use the
@@ -1017,14 +1018,14 @@ class ParsnipModel(nn.Module):
         Parameters
         ----------
         result : dict
-            Output of `ParsnipModel.forward`
+            Output of `~ParsnipModel.forward`
         return_components : bool, optional
             Whether to return the individual parts of the loss function, by default
             False
 
         Returns
         -------
-        float or `torch.FloatTensor`
+        float or `~torch.FloatTensor`
             If return_components is False, return a single value representing the loss
             function for a set of light curves. If return_components is True, then we
             return a set of four values representing the negative log likelihood, the KL
@@ -1060,7 +1061,7 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        dataset : `lcdata.Dataset`
+        dataset : `~lcdata.Dataset`
             Dataset to run on
         rounds : int, optional
             Number of rounds to use for evaluation. VAEs are stochastic, so the loss
@@ -1068,7 +1069,7 @@ class ParsnipModel(nn.Module):
             uncertainty on the loss function can be decreased. Default 1.
         return_components : bool, optional
             Whether to return the individual parts of the loss function, by default
-            False. See `ParsnipModel.loss_function` for details.
+            False. See `~ParsnipModel.loss_function` for details.
 
         Returns
         -------
@@ -1103,13 +1104,13 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        dataset : `lcdata.Dataset`
+        dataset : `~lcdata.Dataset`
             Dataset to fit to
         max_epochs : int, optional
             Maximum number of epochs, by default 1000
         augment : bool, optional
             Whether to use augmentation, by default True
-        test_dataset : `lcdata.Dataset`, optional
+        test_dataset : `~lcdata.Dataset`, optional
             Test dataset that will be scored at the end of each epoch, by default None
         """
         # The model is stochastic, so the loss function will have a fair bit of noise.
@@ -1181,14 +1182,14 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        light_curves : `astropy.table.Table` or List[`astropy.table.Table`]
+        light_curves : `~astropy.table.Table` or List[`~astropy.table.Table`]
             Light curve(s) to generate predictions for.
         augment : bool, optional
             Whether to augment the light curve(s), by default False
 
         Returns
         -------
-        `astropy.table.Table` or dict
+        `~astropy.table.Table` or dict
             Table (for multiple light curves) or dict (for a single light curve)
             containing the predictions.
         """
@@ -1216,14 +1217,14 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        dataset : `lcdata.Dataset`
+        dataset : `~lcdata.Dataset`
             Dataset to generate predictions for.
         augment : bool, optional
             Whether to perform augmentation, False by default.
 
         Returns
         -------
-        predictions : `astropy.table.Table`
+        predictions : `~astropy.table.Table`
             astropy Table with one row for each light curve and columns with each of the
             predicted values.
         """
@@ -1366,20 +1367,20 @@ class ParsnipModel(nn.Module):
         This will first generate predictions for the dataset without augmentation,
         and will then generate predictions for the dataset with augmentation the
         given number of times. This returns a dataframe in the same format as
-        `predict_dataset`, but with the following additional columns:
+        `~predict_dataset`, but with the following additional columns:
         - original_object_id: the original object_id for each augmentation.
         - augmented: True for augmented light curves, False for original ones.
 
         Parameters
         ----------
-        dataset : `lcdata.Dataset`
+        dataset : `~lcdata.Dataset`
             Dataset to generate predictions for.
         augments : int, optional
             Number of times to augment the dataset, by default 10
 
         Returns
         -------
-        predictions : `astropy.table.Table`
+        predictions : `~astropy.table.Table`
             astropy Table with one row for each light curve and columns with each of the
             predicted values.
         """
@@ -1454,7 +1455,7 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        light_curve : `astropy.table.Table`
+        light_curve : `~astropy.table.Table`
             Light curve to predict
         sample : bool, optional
             If True, sample from the latent variable posteriors. Otherwise,
@@ -1469,11 +1470,11 @@ class ParsnipModel(nn.Module):
 
         Returns
         -------
-        `numpy.ndarray`
+        `~numpy.ndarray`
             Times that the model was sampled at
-        `numpy.ndarray`
+        `~numpy.ndarray`
             Flux of the model in each band
-        `numpy.ndarray`
+        `~numpy.ndarray`
             Model result from ParsnipModel.forward
         """
         # Figure out where to sample the light curve
@@ -1504,7 +1505,7 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        light_curve : `astropy.table.Table`
+        light_curve : `~astropy.table.Table`
             Light curve
         time : float
             Time to predict the spectrum at
@@ -1516,8 +1517,9 @@ class ParsnipModel(nn.Module):
 
         Returns
         -------
-        `numpy.ndarray`
-            Predicted spectrum at the wavelengths specified by `ParsnipModel.model_wave`
+        `~numpy.ndarray`
+            Predicted spectrum at the wavelengths specified by
+            `~ParsnipModel.model_wave`
         """
         pred_times = [time]
         pred_bands = [0]
@@ -1537,7 +1539,7 @@ class ParsnipModel(nn.Module):
 
         Parameters
         ----------
-        light_curve : `astropy.table.Table`
+        light_curve : `~astropy.table.Table`
             Light curve
         sample : bool, optional
             If True, sample from the latent variable posteriors. Otherwise,
@@ -1545,7 +1547,7 @@ class ParsnipModel(nn.Module):
 
         Returns
         -------
-        `ParsnipSncosmoModel`
+        `~ParsnipSncosmoModel`
             SNCosmo model initialized with the light curve's predicted latent
             representation
         """
@@ -1578,13 +1580,14 @@ class ParsnipModel(nn.Module):
         return model
 
 
-def load_model(path, device='cpu', threads=8):
+def load_model(path=None, device='cpu', threads=8):
     """Load a ParSNIP model.
 
     Parameters
     ----------
-    path : str
-        Path to the model on disk
+    path : str, optional
+        Path to the model on disk, or name of a model. If not specified, the
+        default_model specified in settings.py is loaded.
     device : str, optional
         Torch device to load the model to, by default 'cpu'
     threads : int, optional
@@ -1592,9 +1595,22 @@ def load_model(path, device='cpu', threads=8):
 
     Returns
     -------
-    `ParsnipModel`
+    `~ParsnipModel`
         Loaded model
     """
+    if path is None:
+        path = default_model
+        print(f"Loading default ParSNIP model '{path}'")
+
+    # Figure out if we were given the path to a model or a built-in model.
+    if '.' not in path:
+        # We were given the name of a built-in model.
+        resource_path = f'models/{path}.pt'
+        full_path = pkg_resources.resource_filename('parsnip', resource_path)
+        if not os.path.exists(full_path):
+            raise ValueError(f"No built-in model named '{path}'")
+        path = full_path
+
     # Load the model data
     use_device = parse_device(device)
     settings, state_dict = torch.load(path, use_device)
